import { Transition } from "@headlessui/react";
import useContextMenu from "../hook/contextMenu";
import { useMemo } from "react";

function ContextMenu(props) {
  let { anchorPoint, show } = useContextMenu({ minX: 250 });
  let contextMenuStyle = useMemo(() => {
    let styles = {};
    if (anchorPoint.y < window.innerHeight - 302) {
      styles.top = anchorPoint.y;
    } else {
      styles.bottom = window.innerHeight - anchorPoint.y;
    }

    if (anchorPoint.x < window.innerWidth - 144) {
      styles.left = anchorPoint.x;
    } else {
      styles.right = window.innerWidth - anchorPoint.x;
    }
    return styles;
  }, [anchorPoint]);

  return (
    <Transition
      appear={true}
      show={show}
      enter="transition duration-100 ease-in-out"
      enterFrom="opacity-0 scale-y-50"
      enterTo="opacity-100 scale-y-100"
      leave="transition duration-100"
      leaveFrom="opacity-100 scale-y-100"
      leaveTo="opacity-0 scale-y-50"
      className={"fixed bg-white shadow px-1 select-none origin-top"}
      style={contextMenuStyle}
    >
      <ContextMenuItem>下载</ContextMenuItem>
      <ContextMenuItem>分享</ContextMenuItem>
      <ContextMenuItem>收藏</ContextMenuItem>
      <hr />
      <ContextMenuItem>重命名</ContextMenuItem>
      <ContextMenuItem>移动</ContextMenuItem>
      <ContextMenuItem>查看详细信息</ContextMenuItem>
      <hr />
      <ContextMenuItem important>移到回收站</ContextMenuItem>
    </Transition>
  );
}

function ContextMenuItem(props) {
  return (
    <div
      className={`py-2 px-5 my-0.5  cursor-pointer rounded-xl ${
        props.important
          ? "text-red-500 hover:text-red-700"
          : "text-gray-900 hover:text-gray-500"
      }`}
      onClick={() => {
        alert("click");
      }}
    >
      {props.children}
    </div>
  );
}

export default ContextMenu;
