import { Button, Form, Input, InputGroup, Schema } from "rsuite";
import React from "react";
import Header from "./header";

const registerModel = Schema.Model({
  email: Schema.Types.StringType()
    .isEmail("请输入正确的格式")
    .isRequired("请输入邮箱"),
  password: Schema.Types.StringType()
    .rangeLength(6, 20, "密码长度为6-20位")
    .isRequired("密码不能为空"),
  confirm_password: Schema.Types.StringType()
    .isRequired("确认密码不能为空")
    .addRule(function (value, data) {
      return value === data.password;
    }, "两次密码不一致"),
  nickname: Schema.Types.StringType()
    .isRequired("昵称不能为空")
    .rangeLength(2, 20, "昵称长度为2-20位"),
});

function Register() {
  const formRef = React.useRef();
  const [formValue, setFormValue] = React.useState({});

  let register = () => {
    console.log(formValue);
    if (formRef.current.check()) {
      console.log("校验通过");
    }
  };
  return (
    <div>
      <div className={"grid place-items-center pt-10 w-screen"}>
        <div className={"w-10/12"}>
          <Header title={"注册账号"} />
          <div className={"flex flex-col gap-5"}>
            <Form
              fluid
              model={registerModel}
              checkTrigger="none"
              onChange={setFormValue}
              ref={formRef}
            >
              <Form.Group controlId="email">
                <Form.Control placeholder={"请输入电子邮箱"} name="email" />
              </Form.Group>
              <Form.Group controlId="password">
                <Form.Control
                  placeholder={"设置登录密码"}
                  name="password"
                  type="password"
                />
              </Form.Group>
              <Form.Group controlId="confirm_password">
                <Form.Control
                  placeholder={"请再次输入密码"}
                  name="confirm_password"
                  type="password"
                />
              </Form.Group>
              <Form.Group controlId="nickname">
                <Form.Control placeholder={"请输入昵称"} name="nickname" />
              </Form.Group>
            </Form>
            <Button appearance={"primary"} onClick={register}>
              下一步
            </Button>
            <div className={"text-center"}>
              <a href={"/login"} className={"cursor-pointer w-fit select-none"}>
                已有fileset.io账号？
              </a>
            </div>
          </div>
        </div>
      </div>
    </div>
  );
}

export default Register;
